@@ -161,12 +161,7 @@ fn get_field_statements(
 fn get_name(attrs: &[syn::Attribute]) -> Option<String> {
     attrs
         .iter()
-        .find(|attr| {
-            attr.path
-                .get_ident()
-                .map(|x| x.to_string() == "name")
-                .unwrap_or(false)
-        })
+        .find(|attr| attr.path.get_ident().map(|x| *x == "name").unwrap_or(false))
         .map(|attr| attr.parse_meta().ok())
         .flatten()
         .map(|meta| {
@@ -252,13 +247,8 @@ impl syn::parse::Parse for Idents {
 fn get_cfg_attrs(func: &syn::ItemFn) -> Vec<syn::Attribute> {
     func.attrs
         .iter()
-        .filter(|attr| {
-            attr.path
-                .get_ident()
-                .map(|x| x.to_string() == "cfg")
-                .unwrap_or(false)
-        })
-        .map(|attr| attr.clone())
+        .filter(|attr| attr.path.get_ident().map(|x| *x == "cfg").unwrap_or(false))
+        .cloned()
         .collect()
 }
 
@@ -284,6 +274,7 @@ macro_rules! define_callback_attributes {
                 pub fn $attr_name(_: TokenStream, function: TokenStream) -> TokenStream {
                     let mut function = syn::parse_macro_input!(function as syn::ItemFn);
                     function.sig.abi = Some(syn::parse_quote!(extern "C"));
+                    let vis = &function.vis;
                     let func = &function.sig.ident;
                     let cfgs = crate::get_cfg_attrs(&function);
 
@@ -306,6 +297,39 @@ macro_rules! define_callback_attributes {
                             )
                         }
 
+                        #vis mod #func {
+                            pub fn enable() {
+                                unsafe {
+                                    ::panda::sys::panda_enable_callback(
+                                        ::panda::sys::panda_get_plugin_by_name(
+                                            ::std::concat!(
+                                                ::std::env!("CARGO_PKG_NAME"),
+                                                "\0"
+                                            ).as_ptr() as _
+                                        ),
+                                        ::panda::sys::$const_name,
+                                        ::std::mem::transmute(super::#func as *const ())
+                                    );
+                                }
+                            }
+
+                            pub fn disable() {
+                                println!("plugin: {}", env!("CARGO_PKG_NAME"));
+                                unsafe {
+                                    ::panda::sys::panda_disable_callback(
+                                        ::panda::sys::panda_get_plugin_by_name(
+                                            ::std::concat!(
+                                                ::std::env!("CARGO_PKG_NAME"),
+                                                "\0"
+                                            ).as_ptr() as _
+                                        ),
+                                        ::panda::sys::$const_name,
+                                        ::std::mem::transmute(super::#func as *const ())
+                                    );
+                                }
+                            }
+                        }
+
                         #function
                     ).into()
                 }
@@ -314,6 +338,7 @@ macro_rules! define_callback_attributes {
     }
 }
 
+#[cfg(not(any(feature = "ppc", feature = "mips64")))]
 macro_rules! define_syscalls_callbacks {
     ($(
         $($doc:literal)*
@@ -595,7 +620,7 @@ include!("syscalls/arm.rs");
 #[cfg(feature = "aarch64")]
 include!("syscalls/aarch64.rs");
 
-// PANDA doesn't have PPC support!
+// PANDA doesn't have PPC syscalls support!
 //#[cfg(feature = "ppc")]
 //include!("syscalls/ppc.rs");
 
@@ -604,3 +629,7 @@ include!("syscalls/mips.rs");
 
 #[cfg(feature = "mipsel")]
 include!("syscalls/mipsel.rs");
+
+// PANDA doesn't have MIPS64 syscalls support
+//#[cfg(feature = "mips64")]
+//include!("syscalls/mips64.rs");
